@@ -103,7 +103,35 @@ class ArcReturnJSONObject:
     def get_data(self):
         return self.dict['data']
 
+    def get_result_bool(self):
+        if self.get_result() == self.RESULT_STATE_SUCCESS:
+            return True
+        else:
+            return False
 
+    def log_dict(self, arg):
+        if isinstance(arg, dict):
+            keys = arg.keys()
+            for key in keys:
+                value = arg[key]
+                if isinstance(value, dict):
+                    self.log_dict(value)
+                else:
+                    log.debug(u'  %s : %s' % (key, value))
+        else:
+            log.debug(u'  %s is not dict')
+
+    def log(self, title=None, count=None):
+        if count is not None and title is not None:
+            log.debug(u'  [%s] %s info' % (count, title))
+        elif title is not None:
+            log.debug(u'  %s info' % (title))
+        else:
+            log.debug(u'  ArcReturnJSONObject info')
+
+        log.debug(u'   Result : %s' % (self.get_result()))
+        log.debug(u'   Message : %s' % (self.get_message()))
+        self.log_dict(self.get_data())
 
 
 
